include !headinfo.inc
//
//***********************************************************************<NP>
function SearchHead ( var head )
// O------------------------------------------------------------------------O
// | Function   : Zeichnungskopf ermitteln (suchen)                         |
// U------------------------------------------------------------------------U
// AP    : Funktionswert - Zeichnungskopf
// --------------------------------------------------------------------------
// Author       : P. Artmann                 Datum : 02.02.1996
// Bearbeiter   :
// akt. Stand   : 02.02.1996
// --------------------------------------------------------------------------
// Beschreibung :  Diese Funktion sucht im aktuellen Modell einen
// --------------  Zeichnungskopf.
//                 Wird ein Zeichnungskopf gefunden, wird als Returnwert true,
//                 ansonsten false zurueckgegeben.
// --------------------------------------------------------------------------
// Aenderungen :
// -------------
//***************************************************************************
    //
    ret_value = false            // init. Returnwert
    //
    // Alle Zeichnungskoepfe ermitteln
    //
    koepfe = top.list_user where .actual_type.name in HeadGroup and not .deleted
    //
    anzahl = len (koepfe)        // Anzahl gefundener Koepfe
    //
    if anzahl = 1 then
        head      = koepfe.el_1  // 1. Gruppenelement uebergeben
        ret_value = true         // Zeichnungskopf gefunden
        //
        // Testausgaben
        //
        if HeadTest then
            //
            akt_type = head.actual_type       // aktueller Typ
            akt_name = akt_type.name          // aktueller Name
            //
            `-> Zeichnungskopf : ` [akt_name] nl
            //
            if valid(head.filename) then
                // Einfach nochmal den Dateinamen ausgeben
               `   Dateiname      : ` [head.filename] nl
            end
        end
    else
        if anzahl > 0 then
            // zuviele Zeichnungskoepfe vorhanden !!
            `Achtung : ` [anzahl] ` Zeichnungskoepfe in der Zeichnung !!!` nl
        end
    end
    //
    return (ret_value)                         // Returnwert
end

//***********************************************************************<NP>
function GetHeadSize ( head )
// O------------------------------------------------------------------------O
// | Function   : Zeichnungskopfabmessungen ermitteln                       |
// U------------------------------------------------------------------------U
// EP    : head          - Name des Zeichnungsrahmens (a0_land, a...)
// AP    : group         - Zeichnungskopfabmessungen
//                         Elementnummer und -Information in der Gruppe :
//                         Nr:  Bedeutung
//                          1   DIN/ANSI-Format
//                          2   Gruppe (Abmessungen)
//                              1.Element : Breite  des Zeichnungsrahmens
//                              2.Element : Hoehe   des Zeichnungsrahmens
// --------------------------------------------------------------------------
// Author       : P. Artmann                 Datum : 18.12.1997
// Bearbeiter   :
// akt. Stand   : 18.12.1997
// --------------------------------------------------------------------------
// Beschreibung :  Diese Funktion liefert die Abmessungen des
// --------------  Zeichnungsrahmens
// --------------------------------------------------------------------------
// Aenderungen :
// -------------
//***************************************************************************
//
    HeadSizeGroup = { }

    i       = 1                     // Index in Der Headinfogruppe
    NrInfos = len(HeadGroup)

    while ( i < NrInfos )  do
        KopfName = index (HeadGroup, i)
        if (KopfName = head) then
            // Name gefunden, Info auslesen
            DetInfoGroup  = index (HeadGroup, i + 1 )
            format        = index (DetInfoGroup, 1)
            sizegroup     = index (DetInfoGroup, 2)
            HeadSizeGroup = HeadSizeGroup + format
            HeadSizeGroup = HeadSizeGroup + { sizegroup }

            i = NrInfos + 1         // Beenden
        else
            i = i + 2               // Detailinfos ueberlesen
        end
    end
    return (HeadSizeGroup)
end

//***********************************************************************<NP>
function GetHeadInfo ()
// O------------------------------------------------------------------------O
// | Function   : Informationen ueber den Zeichnungskopf ermitteln          |
// U------------------------------------------------------------------------U
// EP    : -             -
// AP    : group         - Zeichnungskopfinformationen
//                         Elementnummer und -Information in der Gruppe :
//                         Nr:  Bedeutung
//                          1   Dateiname des Zeichnungskopfes
//                          2   Format (A0, ..)
//                          3   Groesse  { Breite, Hoehe }
//                          4   Position { x, y }
//                          5   Bezeichnung
//                          6   Sachnummer
//                          7   Zeichnungsnummer
//                          8   Datum
//                          9   Bearbeiter
// --------------------------------------------------------------------------
// Author       : P. Artmann                 Datum : 18.12.1997
// Bearbeiter   :
// akt. Stand   : 18.12.1997
// --------------------------------------------------------------------------
// Beschreibung :  Diese Funktion liefert wichtige Informationen
// --------------  ueber die im Modell vorhandenen Zeichnungskoepfe.
//
// --------------------------------------------------------------------------
// Aenderungen :
// -------------
//***************************************************************************
    //
    var paper
    var testhead
    var HeadInfoGroup

    HeadInfoGroup = { }

    testhead = SearchHead ( paper )

    if (testhead) then

        // Get filename and fill Headerinfo

        name          =  paper.filename
        HeadInfoGroup = HeadInfoGroup + name

        // remove Pathname and Extension

        spos = 1
        while spos > 0 do
            spos = pos (name,"/")
            if spos = 0 then
                spos = pos (name,"\\")
            end
            name = substr (name,spos+1,len(name))
        end

        name = name - "*.udo"       // remove .udo

        // Get HeaderFormat and Size

        HeadInfoFormat = GetHeadSize (name)

        // reading the paper parameters for output-purpose
        // Init all parameters

        coord       = { }
        Bezeichnung = ""
        Sachnummer  = ""
        ZNummer     = ""
        Datum       = ""
        Bearbeiter  = ""

        if valid (paper.allpars) then
            coord       = paper.allpars.el_1
            Bezeichnung = paper.allpars.el_2.norm
            Sachnummer  = paper.allpars.el_3.norm
            ZNummer     = paper.allpars.el_4.norm
            Datum       = paper.allpars.el_5.norm
            Bearbeiter  = paper.allpars.el_6.norm
        end

        // Fill Infogroup for output

        HeadInfoGroup = HeadInfoGroup + HeadInfoFormat.el_1

        HeadInfoGroup = HeadInfoGroup + { HeadInfoFormat.el_2 }

        HeadInfoGroup = HeadInfoGroup + { { coord.x coord.y } }

        HeadInfoGroup = HeadInfoGroup + Bezeichnung

        HeadInfoGroup = HeadInfoGroup + Sachnummer

        HeadInfoGroup = HeadInfoGroup + ZNummer

        HeadInfoGroup = HeadInfoGroup + Datum

        HeadInfoGroup = HeadInfoGroup + Bearbeiter
    end
    return (HeadInfoGroup)
end


